package com.foreverwin.mesnac.anomaly.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.foreverwin.mesnac.anomaly.dto.AbnormalBillDisposeDto;
import com.foreverwin.mesnac.anomaly.dto.AbnormalBillDto;
import com.foreverwin.mesnac.anomaly.mapper.AbnormalBillDisposeMapper;
import com.foreverwin.mesnac.anomaly.mapper.AbnormalBillMapper;
import com.foreverwin.mesnac.anomaly.model.*;
import com.foreverwin.mesnac.anomaly.service.*;
import com.foreverwin.mesnac.common.constant.Constants;
import com.foreverwin.mesnac.common.enums.HandleEnum;
import com.foreverwin.mesnac.common.helper.NextNumberHelper;
import com.foreverwin.mesnac.common.util.StringUtil;
import com.foreverwin.mesnac.meapi.mapper.*;
import com.foreverwin.mesnac.meapi.model.*;
import com.foreverwin.mesnac.meapi.service.*;
import com.foreverwin.modular.core.exception.BusinessException;
import com.foreverwin.modular.core.util.CommonMethods;
import com.foreverwin.modular.core.util.FrontPage;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.time.LocalDateTime;
import java.util.*;

/**
 * <p>
 * 异常单 服务实现类
 * </p>
 *
 * @author robert
 * @since 2021-07-05
 */
@Service
@Transactional(rollbackFor = Exception.class)
public class AbnormalBillServiceImpl extends ServiceImpl<AbnormalBillMapper, AbnormalBill> implements AbnormalBillService {



    @Autowired
    private AbnormalBillMapper abnormalBillMapper;

    @Autowired
    private NextNumberHelper nextNumberHelper;

    @Autowired
    private NcGroupMapper ncGroupMapper;

    @Autowired
    private AbnormalBillDisposeService abnormalBillDisposeService;

    @Autowired
    private ResrceMapper resrceMapper;

    @Autowired
    private NwaUserService nwaUserService;

    @Autowired
    private NcCodeService ncCodeService;

    @Autowired
    private AbnormalNcCodeService abnormalNcCodeService;

    @Autowired
    private AbnormalCauseService abnormalCauseService;

    @Autowired
    private AbnormalDutyService abnormalDutyService;

    @Autowired
    private AbnormalBillDisposeMapper abnormalBillDisposeMapper;

    @Autowired
    private ShopOrderMapper shopOrderMapper;

    @Autowired
    private NwaUserMapper nwaUserMapper;

    @Autowired
    private RouterService routerService;

    @Autowired
    private WorkCenterService workCenterService;

    @Autowired
    private DataFieldListService dataFieldListService;

    @Autowired
    private UploadPicturesService uploadPicturesService;



    @Override
    public IPage<AbnormalBill> selectPage(FrontPage<AbnormalBill> frontPage, AbnormalBill abnormalBill) {
        QueryWrapper<AbnormalBill> queryWrapper = new QueryWrapper<>();
        queryWrapper.setEntity(abnormalBill);
        return super.page(frontPage.getPagePlus(), queryWrapper);
    }

    @Override
    public List<AbnormalBill> selectList(AbnormalBill abnormalBill) {
        QueryWrapper<AbnormalBill> queryWrapper = new QueryWrapper<>();
        queryWrapper.setEntity(abnormalBill);
        return super.list(queryWrapper);
    }

    @Override
    public String anomalyReportOther(AbnormalBill abnormalBill,
                                     AbnormalBillDispose abnormalBillDispose,
                                     List<String> dutyCauseType,
                                     List<String> dutyType) {
        String message = this.generateAbnormalBill(abnormalBill, abnormalBillDispose, dutyCauseType, dutyType);
        this.saveOrUpdate(abnormalBill);
        abnormalBillDisposeService.saveOrUpdate(abnormalBillDispose);
        return message;
    }

    @Override
    public String anomalyReport(AbnormalBill abnormalBill,
                                AbnormalBillDispose abnormalBillDispose,
                                List<String> ncGroupAndNcCodes,
                                List<String> dutyCauseType,
                                List<String> dutyType) {
        String message = this.generateAbnormalBill(abnormalBill, abnormalBillDispose, dutyCauseType, dutyType);
        //获取当前时间
        LocalDateTime now = LocalDateTime.now();
        //生成不良代码和不良代码组,并把它放到hashMap里面，ncCode是存放在异常单里面的ncCode

        List<String> ncCode = new ArrayList<>();
        List<String> ncGroup = new ArrayList<>();
        StringBuilder ncCodes = new StringBuilder();
        for(String ncGroupAndNcCode:ncGroupAndNcCodes){
            String[] split = ncGroupAndNcCode.split("/");
            ncGroup.add(split[0]);
            ncCode.add(split[1]);
            ncCodes.append(split[1]).append(",");
        }

        ArrayList<AbnormalNcCode> abnormalNcCodes = new ArrayList<>();
        for(int i = 0; i < ncGroup.size(); i ++){
            AbnormalNcCode abnormalNcCode = new AbnormalNcCode();
            //设置异常单BO
            abnormalNcCode.setAbnormalBillBo(abnormalBill.getHandle());
            List<AbnormalNcCode> abnormalNcCodes1 = abnormalNcCodeService.selectList(abnormalNcCode);
            if(abnormalNcCodes1.size() != 0){
                QueryWrapper<AbnormalNcCode> abnormalNcCodeQueryWrapper = new QueryWrapper<>();
                abnormalNcCodeQueryWrapper.setEntity(abnormalNcCode);
                abnormalNcCodeService.remove(abnormalNcCodeQueryWrapper);
            }
            abnormalNcCode.setModifiedUser(CommonMethods.getUser());
            abnormalNcCode.setModifiedDateTime(now);
            abnormalNcCode.setCreatedUser(CommonMethods.getUser());
            abnormalNcCode.setCreatedDateTime(now);
            //设置HANDLE
            abnormalNcCode.setHandle(UUID.randomUUID().toString());
            //设置站点
            abnormalNcCode.setSite(CommonMethods.getSite());
            //设置不合格代码组
            abnormalNcCode.setNcCodeGroup(ncGroup.get(i));
            abnormalNcCode.setNcCode(ncCode.get(i));
            abnormalNcCodes.add(abnormalNcCode);
        }
        if(abnormalNcCodes.size() > 0){
            abnormalNcCodeService.saveOrUpdateBatch(abnormalNcCodes);
            abnormalBill.setNcCode(ncCodes.substring(0,ncCodes.length() - 1));
        }
        this.saveOrUpdate(abnormalBill);
        abnormalBillDisposeService.saveOrUpdate(abnormalBillDispose);
        return message;
    }


    @Override
    public String anomalyReportDevice(AbnormalBill abnormalBill,AbnormalBillDispose abnormalBillDispose) {
        String message = this.generateAbnormalBill(abnormalBill, abnormalBillDispose, null, null);

        List<NcCode> ncByNG = ncCodeService.findNcByNG(abnormalBill.getMessageType(), abnormalBill.getNcCode());
        if(ncByNG == null || ncByNG.size() <= 0){
            throw BusinessException.build("该消息类型下没有该不良代码");
        }
        this.saveOrUpdate(abnormalBill);
        abnormalBillDisposeService.saveOrUpdate(abnormalBillDispose);
        return message;
    }

    @Override
    public HashMap<String, Object> init(String messageType,String type) {
        HashMap<String, Object> hashMap = new HashMap<>();
        String site = CommonMethods.getSite();
        //消息类型
        if(!StringUtil.isBlank(messageType)){
            List<NcCode> ncByNG = ncCodeService.findNcByNG(messageType,null);

            hashMap.put("ncByNG",ncByNG);
        }
        //工作中心
        WorkCenter workCenter = new WorkCenter();
        workCenter.setWcCategory("LEVEL4");
        workCenter.setSite(site);
        List<WorkCenter> workCenterList = workCenterService.selectList(workCenter);
        hashMap.put("workCenter",workCenterList);
        //原因分类
        NcCode ncCode = new NcCode();
        ncCode.setSite(site);
        ncCode.setNcCategory("REPAIR");
        List<NcCode> ncCodeList = ncCodeService.selectList(ncCode);
        hashMap.put("causeType",ncCodeList);
        //责任部门
        DataField dataField = new DataField();
        dataField.setSite(site);
        dataField.setDataField("RESPONSIBILITY_DEPARTMENT");
        List<DataField> dutyDepartList = dataFieldListService.findDataFieldListById(dataField);
        hashMap.put("dutyDepart",dutyDepartList);
        //责任分类
        dataField.setDataField("RESPONSIBILITY_TYPE");
        List<DataField> dutyTypeList = dataFieldListService.findDataFieldListById(dataField);
        hashMap.put("dutyType",dutyTypeList);
        //当前登录用户的fullName
        NwaUser nwaUser = new NwaUser();
        nwaUser.setSite(site);
        nwaUser.setUserName(CommonMethods.getUser());
        List<NwaUser> nwaUsers = nwaUserService.selectList(nwaUser);
        if(nwaUsers != null){
            hashMap.put("currentUser",nwaUsers.get(0).getFullName());
        }
        //初始化异常单号
        String abnormalNo = null;
        //生成异常单号
        if("Q".equals(type)){//其他异常
            abnormalNo = nextNumberHelper.getNextNumber(site, "ABNORMAL_OTHER", 1, null).get(0);
        }else if("Z".equals(type)){//质量异常
            abnormalNo = nextNumberHelper.getNextNumber(site, "ABNORMAL_QUALITY", 1, null).get(0);
        }else if("S".equals(type)){//设备异常
            abnormalNo = nextNumberHelper.getNextNumber(site, "ABNORMAL_DEVICE", 1, null).get(0);
        }
        hashMap.put("abnormalNo",abnormalNo);

        return hashMap;
    }

    @Override
    public List<AbnormalBillDto> backLog(AbnormalBillDto abnormalBillDto) {
        String language = LocaleContextHolder.getLocale().getLanguage();
        return abnormalBillMapper.backLog(abnormalBillDto, language);

    }

    @Override
    public AbnormalBillDisposeDto findAllByAbnormalNo(AbnormalBill abnormalBill) {
        String site = CommonMethods.getSite();
        String local=LocaleContextHolder.getLocale().getLanguage();
        abnormalBill.setSite(site);
        if(StringUtil.isEmpty(abnormalBill.getAbnormalNo())){
            return null;
        }
        return abnormalBillDisposeMapper.findAllByAbnormalNo(abnormalBill,local);

    }

    @Override
    public AbnormalBillDto findAllByAbnormalNoDevice(AbnormalBill abnormalBill) {
        String site = CommonMethods.getSite();
        String local=LocaleContextHolder.getLocale().getLanguage();
        abnormalBill.setSite(site);
        if(StringUtil.isEmpty(abnormalBill.getAbnormalNo())){
            return null;
        }
        return abnormalBillMapper.findAllByAbnormalNoDevice(abnormalBill,local);
    }

    @Override
    public void resProcessing(AbnormalBill abnormalBill) {
        String site = CommonMethods.getSite();
        String user = "";
        if(StringUtil.isBlank(abnormalBill.getResponseUser())){
            user = CommonMethods.getUser();
        }
        LocalDateTime now = LocalDateTime.now();
        abnormalBill.setSite(site);
        abnormalBill.setResponseUser(user);
        abnormalBill.setResponseDateTime(now);
        abnormalBill.setStatus(Constants.RESPONSE);
        this.saveOrUpdate(abnormalBill);
    }

    @Override
    public void programConfirm(AbnormalBill abnormalBill,AbnormalBillDispose abnormalBillDispose) {
        String site = CommonMethods.getSite();
        String user = CommonMethods.getUser();
        LocalDateTime now = LocalDateTime.now();
        abnormalBillDispose.setHandle(HandleEnum.Z_ABNORMAL_BILL_DISPOSE.getHandle(site,abnormalBill.getAbnormalNo()));

        if(!StringUtil.isBlank(abnormalBillDispose.getRouterBo())){
            //分割该工艺路线
            String[] routerSplit = abnormalBillDispose.getRouterBo().split(",");
            //判断该返修工艺是否正确
            Router router = new Router();
            router.setSite(site);
            router.setRouter(routerSplit[1]);
            router.setRouterType(routerSplit[2]);
            router.setCurrentRevision("true");
            List<Router> routers = routerService.selectList(router);
            if(routers == null || routers.size() == 0){
                throw BusinessException.build("该返修工艺不存在");
            }
        }
        //判断返修工单是否正确
        if(!StringUtil.isBlank(abnormalBillDispose.getResolveShopOrder())){
            ShopOrder shopOrder = shopOrderMapper.selectById(HandleEnum.SHOP_ORDER.getHandle(site, abnormalBillDispose.getResolveShopOrder()));
            if(shopOrder == null){
                throw BusinessException.build("该返修工单不存在");
            }
        }
        //发送用户
        String[] split = abnormalBillDispose.getResolveSendUser().split(",");
        List<String> strings = Arrays.asList(split);
        int length = nwaUserMapper.checkUser(site, strings);
        if(length != strings.size()){
            throw BusinessException.build("发送用户填报错误");
        }


        //设置解决方案的处理时间和处理人
        abnormalBillDispose.setResolveDateTime(now);
        abnormalBillDispose.setResolveUser(user);
        abnormalBill.setStatus(Constants.PROGRAM_CONFIRM);
        abnormalBillDisposeService.saveOrUpdate(abnormalBillDispose);
        this.saveOrUpdate(abnormalBill);

    }

    @Override
    public void dutyConfirm(AbnormalBill abnormalBill, AbnormalBillDispose abnormalBillDispose) {
        String site = CommonMethods.getSite();
        String user = CommonMethods.getUser();
        LocalDateTime now = LocalDateTime.now();
        abnormalBillDispose.setHandle(HandleEnum.Z_ABNORMAL_BILL_DISPOSE.getHandle(site,abnormalBill.getAbnormalNo()));

        //判断判责提交是否已经填写
        //AbnormalBillDispose abnormalBillDispose1 = abnormalBillDisposeMapper.selectById(abnormalBillDispose.getHandle());
        AbnormalBill abnormalBill1 = abnormalBillMapper.selectById(abnormalBill.getHandle());
        if(!"N".equals(abnormalBill1.getStatus()) && !"X".equals(abnormalBill1.getStatus()) ){
            throw BusinessException.build("该异常单已经判责提交");
        }
        abnormalBill.setStatus(Constants.CORRECTION_CONFIRM);
        abnormalBillDispose.setDutyDateTime(now);
        abnormalBillDispose.setDutyUser(user);

        nwaUserService.checkUserGroup(abnormalBillDispose.getDutySendUserGroup());
        this.saveOrUpdate(abnormalBill);
        abnormalBillDisposeService.saveOrUpdate(abnormalBillDispose);

    }

    @Override
    public void anomalyShutDown(AbnormalBill abnormalBill, AbnormalBillDispose abnormalBillDispose) {
        String site = CommonMethods.getSite();
        String user = CommonMethods.getUser();
        LocalDateTime now = LocalDateTime.now();
        abnormalBillDispose.setHandle(HandleEnum.Z_ABNORMAL_BILL_DISPOSE.getHandle(site,abnormalBill.getAbnormalNo()));

        //判断判责提交是否还没有进行填写
        AbnormalBillDispose abnormalBillDispose1 = abnormalBillDisposeMapper.selectById(abnormalBillDispose.getHandle());
        if(abnormalBillDispose1 != null){
            if(StringUtil.isBlank(abnormalBillDispose1.getDutyCauseType())){
                throw BusinessException.build("该异常单还没有进行判责提交");
            }
        }
        abnormalBill.setStatus(Constants.SHUT_DOWN);
        abnormalBillDispose.setClosedUser(user);
        abnormalBillDispose.setClosedDateTime(now);
        this.saveOrUpdate(abnormalBill);
        abnormalBillDisposeService.saveOrUpdate(abnormalBillDispose);


    }

    @Override
    public String generateAbnormalBill(AbnormalBill abnormalBill, AbnormalBillDispose abnormalBillDispose,List<String> dutyCauseType,List<String> dutyType) {
        String site = CommonMethods.getSite();
        String message = null;
        LocalDateTime currentTime = LocalDateTime.now();
        String user = CommonMethods.getUser();
        if(StringUtil.isBlank(abnormalBill.getAbnormalNo())) {
            throw BusinessException.build("异常单号不存在");
        }
        abnormalBill.setHandle(HandleEnum.Z_ABNORMAL_BILL.getHandle(site,abnormalBill.getAbnormalNo()));
        //更新的时候，判断该异常当的状态是否为新建
        AbnormalBill abnormalBill1 = abnormalBillMapper.selectById(abnormalBill.getHandle());
        if(abnormalBill1 != null){
            if(!"N".equals(abnormalBill1.getStatus())){
                throw BusinessException.build("该异常单已经被人处理，不能进行更新");
            }
            message = "更新成功";
        }else{
            message = "保存成功";
        }
        abnormalBillDispose.setAbnormalBillBo(abnormalBill.getHandle());
        abnormalBillDispose.setHandle(HandleEnum.Z_ABNORMAL_BILL_DISPOSE.getHandle(site,abnormalBill.getAbnormalNo()));

        //设置责任划分填报人和填报时间
        abnormalBillDispose.setDutyUser(user);
        abnormalBillDispose.setDutyDateTime(currentTime);

        ArrayList<AbnormalCause> causeTypes = new ArrayList<>();
        //判断原因分类是否为空
        if(dutyCauseType != null && dutyCauseType.size() >= 1){
            for(String cause:dutyCauseType){
                AbnormalCause abnormalCause = new AbnormalCause();
                String uuid = UUID.randomUUID().toString();
                abnormalCause.setSite(site);
                abnormalCause.setAbnormalBillBo(abnormalBill.getHandle());
                abnormalCause.setAbnormalBillDisposeBo(abnormalBillDispose.getHandle());
                List<AbnormalCause> abnormalCauses = abnormalCauseService.selectList(abnormalCause);
                if(abnormalCauses.size() != 0){
                    QueryWrapper<AbnormalCause> abnormalCauseQueryWrapper = new QueryWrapper<>();
                    abnormalCauseQueryWrapper.setEntity(abnormalCause);
                    abnormalCauseService.remove(abnormalCauseQueryWrapper);
                }
                abnormalCause.setHandle(uuid);
                abnormalCause.setAbnormalCauseNo(cause);
                abnormalCause.setCreatedDateTime(currentTime);
                abnormalCause.setCreatedUser(user);
                abnormalCause.setModifiedUser(user);
                abnormalCause.setModifiedDateTime(currentTime);
                causeTypes.add(abnormalCause);
            }
        }
        ArrayList<AbnormalDuty> dutyTypes = new ArrayList<>();
        //判断责任分类是否为空
        if(dutyType != null && dutyType.size() >= 1){
            for(String duty:dutyType){
                AbnormalDuty abnormalDuty = new AbnormalDuty();
                String uuid = UUID.randomUUID().toString();
                abnormalDuty.setSite(site);
                abnormalDuty.setAbnormalBillBo(abnormalBill.getHandle());
                abnormalDuty.setAbnormalBillDisposeBo(abnormalBillDispose.getHandle());
                List<AbnormalDuty> abnormalDuties = abnormalDutyService.selectList(abnormalDuty);
                if(abnormalDuties.size() != 0){
                    QueryWrapper<AbnormalDuty> abnormalDutyQueryWrapper = new QueryWrapper<>();
                    abnormalDutyQueryWrapper.setEntity(abnormalDuty);
                    abnormalDutyService.remove(abnormalDutyQueryWrapper);
                }
                abnormalDuty.setHandle(uuid);
                abnormalDuty.setAbnormalDutyNo(duty);
                abnormalDuty.setModifiedUser(user);
                abnormalDuty.setModifiedDateTime(currentTime);
                abnormalDuty.setCreatedDateTime(currentTime);
                abnormalDuty.setCreatedUser(user);
                dutyTypes.add(abnormalDuty);
            }
        }

        //设置创建时间和更新时间
        if(abnormalBillMapper.selectById(abnormalBill.getHandle()) == null){
            abnormalBill.setCreatedDateTime(currentTime);
            abnormalBill.setCreatedUser(user);
            abnormalBillDispose.setCreatedDataTime(currentTime);
            abnormalBillDispose.setCreatedUser(user);
        }
        abnormalBill.setModifiedDateTime(currentTime);
        abnormalBill.setModifiedUser(user);
        abnormalBillDispose.setModifiedDateTime(currentTime);
        abnormalBillDispose.setModifiedUser(user);

        //判断SFC、设备编号、消息类型是否不正确或为空
        if(StringUtil.isBlank(abnormalBill.getSfc()) && !"S".equals(abnormalBill.getType())){
            throw BusinessException.build("产品条码不能为空");
        }
//        if(StringUtil.isBlank(abnormalBill.getResrce())){
//            throw BusinessException.build("设备编号不能为空");
//        }
        if(!StringUtil.isBlank(abnormalBill.getMessageType())){
            NcGroup messageType = ncGroupMapper.selectById(HandleEnum.NC_GROUP.getHandle(site, abnormalBill.getMessageType()));
            if(messageType == null){
                throw BusinessException.build("该消息类型不存在");
            }
        }

//        Resrce resrce = resrceMapper.selectById(HandleEnum.RESOURCE.getHandle(site, abnormalBill.getResrce()));
//        if(resrce == null){
//            throw BusinessException.build("该设备编号不存在");
//        }
        //判断不良品数量和问题数量是否为正整数
        try {
            if(!StringUtil.isBlank(abnormalBill.getNcQty()) && Integer.parseInt(abnormalBill.getNcQty()) < 0) {
                throw BusinessException.build("不良品数量必须大于0");
            }
            if(!StringUtil.isBlank(abnormalBill.getPbQty()) && Integer.parseInt(abnormalBill.getPbQty()) < 0){
                throw BusinessException.build("问题数量必须大于0");
            }
        }catch (NumberFormatException num){
            throw BusinessException.build("问题数量或不良品数量必须为一个正整数");
        }
        //判断输入的用户组是否正确，并返回对应的用户
        nwaUserService.checkUserGroup(abnormalBillDispose.getDutySendUserGroup());
        //插入原因分类和责任分类
        if(dutyTypes.size() > 0){
            abnormalDutyService.saveOrUpdateBatch(dutyTypes);
        }
        if(causeTypes.size() > 0){
            abnormalCauseService.saveOrUpdateBatch(causeTypes);
        }
        //放置图片
        this.fileUpload(abnormalBill);

        return message;

    }

    @Override
    public void cancelBrowse(String handle, String cancelBrowse,String code) {
        LocalDateTime now = LocalDateTime.now();
        AbnormalBill abnormalBill = abnormalBillMapper.selectById(handle);
        abnormalBill.setStatus(Constants.CANCEL);
        abnormalBill.setCancelReason(cancelBrowse);
        if(!StringUtil.isBlank(code)){
            abnormalBill.setCancelCode(code);
        }
        abnormalBill.setCancelUser(CommonMethods.getUser());
        abnormalBill.setCancelDateTime(now);
        this.saveOrUpdate(abnormalBill);
    }

    @Override
    public void fileUpload(AbnormalBill abnormalBill){
        String user = CommonMethods.getUser();
        LocalDateTime now = LocalDateTime.now();
        List<String> name = null;
        if(StringUtil.notBlank(abnormalBill.getFileName())){
            name = Arrays.asList(abnormalBill.getFileName().split(","));
        }
        if(name != null && name.size() != 0){
            //String uuid = UUID.randomUUID().toString();
            UploadPictures uploadPictures = new UploadPictures();
            uploadPictures.setHandle("UploadPicturesBO:"+abnormalBill.getSite()+","+abnormalBill.getAbnormalNo());
            uploadPictures.setSite(abnormalBill.getSite());
            uploadPictures.setPicturePath(abnormalBill.getFilePath());
            StringBuilder pictureAddress = new StringBuilder();
            for (int i = 0; i <= name.size() -1; i++) {
                if(i != name.size() -1){
                    pictureAddress.append(abnormalBill.getFilePath()).append("/").append(name.get(i)).append(",");
                }else{
                    pictureAddress.append(abnormalBill.getFilePath()).append("/").append(name.get(i));
                }
            }
            uploadPictures.setPictureAddress(pictureAddress.toString());
            uploadPictures.setObjectBo(abnormalBill.getHandle());
            uploadPictures.setNum(abnormalBill.getFileNum());
            uploadPictures.setType("ABNORMAL");
            uploadPictures.setCreatedUser(user);
            uploadPictures.setCreatedDateTime(now);
            uploadPictures.setModifiedUser(user);
            uploadPictures.setModifiedDateTime(now);
            uploadPicturesService.saveOrUpdate(uploadPictures);
        }
    }

    @Override
    public UploadPictures findUploadPictureByAbnormalBo(AbnormalBill abnormalBill) {
        String site = CommonMethods.getSite();
        UploadPictures uploadPictures = new UploadPictures();
        uploadPictures.setSite(site);
        uploadPictures.setObjectBo(abnormalBill.getHandle());
        List<UploadPictures> uploadPictures1 = uploadPicturesService.selectList(uploadPictures);
        if(uploadPictures1 != null && uploadPictures1.size() == 1){
            return  uploadPictures1.get(0);
        }
        return null;
    }
}






