package com.foreverwin.mesnac.dispatch.service.impl;

import com.foreverwin.mesnac.common.enums.HandleEnum;
import com.foreverwin.mesnac.dispatch.model.IssueItem;
import com.foreverwin.mesnac.dispatch.mapper.IssueItemMapper;
import com.foreverwin.mesnac.dispatch.model.ItemBatch;
import com.foreverwin.mesnac.dispatch.service.IssueItemService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.foreverwin.mesnac.dispatch.service.ItemBatchService;
import com.foreverwin.mesnac.meapi.model.Inventory;
import com.foreverwin.mesnac.meapi.model.Item;
import com.foreverwin.mesnac.meapi.service.InventoryService;
import com.foreverwin.mesnac.meapi.service.ItemService;
import com.foreverwin.modular.core.exception.BusinessException;
import com.sap.me.common.MaterialType;
import org.springframework.stereotype.Service;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;

import java.util.HashMap;
import java.util.List;
import java.util.Map;


/**
 * <p>
 * 车间发料 服务实现类
 * </p>
 *
 * @author Leon.L
 * @since 2021-07-09
 */
@Service
@Transactional(rollbackFor = Exception.class)
public class IssueItemServiceImpl extends ServiceImpl<IssueItemMapper, IssueItem> implements IssueItemService {

    @Autowired
    private ItemService itemService;
    @Autowired
    private IssueItemMapper issueItemMapper;
    @Autowired
    private ItemBatchService itemBatchService;
    @Autowired
    private InventoryService inventoryService;


    @Override
    public Map<String, Object> scanIssueInventory(String site, String item, String inventory) {
        Item itemModel = itemService.selectCurrent(site, item);
        if (itemModel == null) {
            throw BusinessException.build("物料【"  +item+"】当前版本不存在！");
        }
        String itemBo = itemModel.getHandle();
        String materialType = itemModel.getMaterialType();

        Map<String, Object> map = new HashMap<>();
        //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
        if (MaterialType.RAW.value().equals(materialType)){
            //原材料
            List<ItemBatch> itemBatchList = itemBatchService.findItemBatch(site, item, inventory);
            if (itemBatchList == null || itemBatchList.size() <= 0) {
                throw BusinessException.build("扫描的物料条码【 "+ inventory +" 】不存在！");
            }
        } else {
            //半成品
            String inventoryBo = HandleEnum.INVENTORY.getHandle(site, inventory);
            Inventory inventoryModel = inventoryService.getById(inventoryBo);
            if (inventoryModel == null) {
                throw BusinessException.build("扫描的物料条码【 "+ inventory +" 】不存在！");
            }
            String invItemBo = inventoryModel.getItemBo();
            if (invItemBo.equals(itemBo)) {
                throw BusinessException.build("扫描的物料条码【 "+ inventory +" 】不是物料【"+ item +"】的库存！");
            }
            map.put("qty", inventoryModel.getQtyOnHand());
        }


        return map;
    }
}