package com.foreverwin.mesnac.dispatch.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.foreverwin.mesnac.common.enums.HandleEnum;
import com.foreverwin.mesnac.common.util.NumberUtil;
import com.foreverwin.mesnac.common.util.StringUtil;
import com.foreverwin.mesnac.dispatch.mapper.SurplusItemReturnMapper;
import com.foreverwin.mesnac.dispatch.model.SurplusItemReturn;
import com.foreverwin.mesnac.dispatch.service.SurplusItemReturnService;
import com.foreverwin.mesnac.meapi.model.Inventory;
import com.foreverwin.mesnac.meapi.service.InventoryService;
import com.foreverwin.modular.core.exception.BusinessException;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.Map;

/**
 * <p>
 * 余料退回 服务实现类
 * </p>
 *
 * @author Leon.L
 * @since 2021-07-10
 */
@Service
@Transactional(rollbackFor = Exception.class)
public class SurplusItemReturnServiceImpl extends ServiceImpl<SurplusItemReturnMapper, SurplusItemReturn> implements SurplusItemReturnService {


    @Autowired
    private InventoryService inventoryService;
    @Autowired
    private SurplusItemReturnMapper surplusItemReturnMapper;


    @Override
    public Map<String, Object> getInventoryData(String site, String inventory) {
        String inventoryBo = HandleEnum.INVENTORY.getHandle(site, inventory);
        Inventory inventoryModel = inventoryService.getById(inventoryBo);
        if (inventoryModel == null) {
            throw BusinessException.build("物料条码【" + inventory +"】不存在！");
        }
        if (inventoryModel.getQtyOnHand().doubleValue() <= 0) {
            throw BusinessException.build("物料条码【" + inventory +"】没有可用数量！");
        }

        //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
        Map<String, Object> map = surplusItemReturnMapper.selectInventoryData(inventoryBo);
        if (map == null || map.size() <= 0) {
            throw BusinessException.build("物料条码【" + inventory +"】不存在！");
        }
        String item = (String) map.get("ITEM");
        String perMater = (String) map.get("PER_METER");
        String perSquareMeter = (String) map.get("PER_SQUARE_METER");
        if (StringUtil.isBlank(perMater) && StringUtil.isBlank(perSquareMeter)) {
            throw BusinessException.build("物料【" +item+ "】的自定义字段【每米重量】和【每平米重量】都没维护！");
        }
        if (StringUtil.notBlank(perMater) && !NumberUtil.isNumber(perMater)) {
            throw BusinessException.build("物料【" +item+ "】的自定义字段【每米重量】只能维护数值！");
        }
        if (StringUtil.notBlank(perSquareMeter) && !NumberUtil.isNumber(perSquareMeter)) {
            throw BusinessException.build("物料【" +item+ "】的自定义字段【每平米重量】只能维护数值！");
        }

        return map;
    }
}